bytecode_encoder_bytecode_encoder

Function bytecode_encoder_bytecode_encoder 

pub fn bytecode_encoder_bytecode_encoder()
In Rust, a virtual destructor is handled by the trait’s vtable and Drop. Since BytecodeEncoder is a trait, we do not need to explicitly implement a destructor method.