Functions
- bytecode_
encoder_ bytecode_ encoder - In Rust, a virtual destructor is handled by the trait’s vtable and
Drop. SinceBytecodeEncoderis a trait, we do not need to explicitly implement a destructor method.
Drop.
Since BytecodeEncoder is a trait, we do not need to explicitly implement a destructor method.